==> SCENARIbuilder_3.3.0alpha_lin.tgz: bin/scTest/components/scTestClh.js <==
/*
 * LICENCE[[
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1/CeCILL 2.O
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is utc.fr code.
 *
 * The Initial Developer of the Original Code is
 * sylvain.spinelli@kelis.fr on behalf of UTC
 *
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * or the CeCILL Licence Version 2.0 (http://www.cecill.info/licences.en.html),
 * in which case the provisions of the GPL, the LGPL or the CeCILL are applicable
 * instead of those above. If you wish to allow use of your version of this file
 * only under the terms of either the GPL, the LGPL or the CeCILL, and not to allow
 * others to use your version of this file under the terms of the MPL, indicate
 * your decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL, the LGPL or the CeCILL. If you do not
 * delete the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL, the LGPL or the CeCILL.
 * ]]LICENCE
 */

const nsISupports              = Components.interfaces.nsISupports;

const nsICategoryManager       = Components.interfaces.nsICategoryManager;
const nsIComponentRegistrar    = Components.interfaces.nsIComponentRegistrar;
const nsICommandLine           = Components.interfaces.nsICommandLine;
const nsICommandLineHandler    = Components.interfaces.nsICommandLineHandler;
const nsIFactory               = Components.interfaces.nsIFactory;
const nsIModule                = Components.interfaces.nsIModule;
const nsIPrefBranch            = Components.interfaces.nsIPrefBranch;
const nsISupportsString        = Components.interfaces.nsISupportsString;
const nsIWindowWatcher         = Components.interfaces.nsIWindowWatcher;
const nsIDOMWindow			   = Components.interfaces.nsIDOMWindow;

/**
 * This file provides a generic default command-line handler.
 *
 * It opens the chrome window specified by the pref "toolkit.defaultChromeURI"
 * the arguments passed to the window are the nsICommandLine instance.
 *
 * It doesn't do anything if the pref is unset.
 */

var scTestClh = {
  /* nsISupports */

  QueryInterface : function clh_QI(iid) {
    if (iid.equals(nsICommandLineHandler) ||
        iid.equals(nsIFactory) ||
        iid.equals(nsISupports))
      return this;

    throw Components.results.NS_ERROR_NO_INTERFACE;
  },

  /* nsICommandLineHandler */

  handle : function clh_handle(pCmdLine) {
	if (pCmdLine.preventDefault) return;
	
	var vPrefs = Components.classes["@mozilla.org/preferences-service;1"].getService(nsIPrefBranch);
	var vConsoleService = Components.classes["@mozilla.org/consoleservice;1"].getService(Components.interfaces.nsIConsoleService);
	
	try {
		var chromeURI = vPrefs.getCharPref("toolkit.defaultChromeURI");
		
		var vExtMgrService = Components.classes["@mozilla.org/extensions/manager;1"].getService(Components.interfaces.nsIExtensionManager);
		
		var vWinWatch = Components.classes["@mozilla.org/embedcomp/window-watcher;1"].getService(nsIWindowWatcher);
		var vEnum = vWinWatch.getWindowEnumerator(null);
		 
		//On update le chrome
		var vChromeCode = pCmdLine.handleFlagWithParam("chromeCode", true);
		var vChromeContentUrl = pCmdLine.handleFlagWithParam("chromeContentUrl", true);
		var vManifest = "content " + vChromeCode + " " + vChromeContentUrl + "\n";
		vManifest    +=  "overlay chrome://scenaricms/content/wspmgr/packlist " + vChromeContentUrl + "pack.xml\n";
		
		var vFolderService = Components.classes["@mozilla.org/file/directory_service;1"].getService(Components.interfaces.nsIProperties);
		var vFile = vFolderService.get("ProfD", Components.interfaces.nsIFile);
		vFile.append("extensions");
		if( ! vFile.exists()) vFile.create(Components.interfaces.nsIFile.DIRECTORY_TYPE, 0755);
		vFile.append("modeltest@scenari-platform.org");
		
		if( ! vFile.exists()) {
			//Nouveau profile, on cre l'extension
			vFile.create(Components.interfaces.nsIFile.DIRECTORY_TYPE, 0755);
			var vInstallRdf = vFile.clone();
			
			vInstallRdf.append("install.rdf");
			vInstallContent = '<?xml version="1.0" encoding="ISO-8859-1"?><RDF xmlns="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:em="http://www.mozilla.org/2004/em-rdf#"><Description about="urn:mozilla:install-manifest">';
			vInstallContent += '<em:id>modeltest@scenari-platform.org</em:id><em:name>modeltest</em:name><em:type>2</em:type><em:version>0.0.0</em:version><em:description>modeltest</em:description><em:creator>SCENARI</em:creator>';
			vInstallContent += '<em:targetApplication><Description><em:id>{96812ADD-F6D9-482A-B0EF-D4F1DE71D0E0}</em:id><em:minVersion>1.0</em:minVersion><em:maxVersion>99.*</em:maxVersion></Description></em:targetApplication>';
			vInstallContent += '</Description></RDF>';
			var vOutputStream = Components.classes["@mozilla.org/network/file-output-stream;1"].createInstance( Components.interfaces.nsIFileOutputStream );
			vOutputStream.init(vInstallRdf, 0x04 | 0x08 | 0x20, 0644, 0 );
			vOutputStream.write(vInstallContent, vInstallContent.length);
			vOutputStream.close();
					
			//Rechargement des extensions.
			vExtMgrService.start(pCmdLine);

		}
			
		//On met  jour le chrome
		vFile.append("chrome.manifest");
		var vOutputStream = Components.classes["@mozilla.org/network/file-output-stream;1"].createInstance(Components.interfaces.nsIFileOutputStream);
		vOutputStream.init(vFile, 0x04 | 0x08 | 0x20, 0644, 0 );
		vOutputStream.write(vManifest, vManifest.length);
		vOutputStream.close();
		//On reload le chrome
		var vChromeRegistry = Components.classes["@mozilla.org/chrome/chrome-registry;1"].getService(Components.interfaces.nsIChromeRegistry);
		vChromeRegistry.checkForNewChrome();
		
		//On purge le cache d'image
		var vCacheImg = Components.classes["@mozilla.org/image/cache;1"].getService(Components.interfaces.imgICache);
		vCacheImg.clearCache(true);
	
		//On met  jour l'atelier
		var vWspCode = pCmdLine.handleFlagWithParam("wspCode", true);
		var vUrlServer = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch).getCharPref("scenari.defaultUrlServerLocal");
		var vWspReg = Components.classes["@scenari.com/wspregistryservice;1"].getService(Components.interfaces.scIWspRegistryService);
		vWspReg.removeDataServer(vUrlServer);
		vWspReg.addDataServer(vUrlServer, "");
		vWspReg.addWsp(vUrlServer, vWspCode, "", true);
		
		
		//On ouvre une nouvelle fenetre.
		var vNewWin = vWinWatch.openWindow(null, chromeURI, "_blank", "chrome,dialog=no,all", pCmdLine);
	
		pCmdLine.preventDefault = true;
		
		//On ferme toutes les autres fentres
		while (vEnum.hasMoreElements()) {
			var vDomWindow = vEnum.getNext().QueryInterface(nsIDOMWindow);
			if(vNewWin !== vDomWindow) try{vDomWindow.close();} catch (e) {}
		}
	} catch (e) {
		debug("init Failed : "+e);
	}
	
  },

  helpInfo : "SCENARI test",

  /* nsIFactory */
  createInstance : function mdh_CI(outer, iid) {
    if (outer != null) throw Components.results.NS_ERROR_NO_AGGREGATION;
    return this.QueryInterface(iid);
  },

  lockFactory : function mdh_lock(lock) {
    /* no-op */
  }
};

function debug(pText){
	var vConsoleService = Components.classes["@mozilla.org/consoleservice;1"].getService(Components.interfaces.nsIConsoleService);
	vConsoleService.logStringMessage(pText);
}
function dialogAlert(pText, pTitle){
	var vService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
	vService.alert(null, pTitle ? pTitle : "SCENARI - Message", pText);
}



const clh_contractID = "@scenari/scenaritest-clh;1";
const clh_CID = Components.ID("{3CAE0595-E91E-402C-8936-4B886A7DE3FD}");

var Module = {
  /* nsISupports */

  QueryInterface : function mod_QI(iid) {
    if (iid.equals(nsIModule) ||
        iid.equals(nsISupports))
      return this;

    throw Components.results.NS_ERROR_NO_INTERFACE;
  },

  /* nsIModule */

  getClassObject : function mod_gch(compMgr, cid, iid) {
    if (cid.equals(clh_CID))
      return scTestClh.QueryInterface(iid);

    throw components.results.NS_ERROR_FAILURE;
  },

  registerSelf : function mod_regself(compMgr, fileSpec, location, type) {
    var compReg = compMgr.QueryInterface(nsIComponentRegistrar);

    compReg.registerFactoryLocation(clh_CID,
                                    "scTestClh",
                                    clh_contractID,
                                    fileSpec,
                                    location,
                                    type);

    var catMan = Components.classes["@mozilla.org/categorymanager;1"]
                           .getService(nsICategoryManager);

    catMan.addCategoryEntry("command-line-handler",
                            "m-scenaritest",
                            clh_contractID, true, true);
  },

  unregisterSelf : function mod_unreg(compMgr, location, type) {
    var compReg = compMgr.QueryInterface(nsIComponentRegistrar);
    compReg.unregisterFactoryLocation(clh_CID, location);

    var catMan = Components.classes["@mozilla.org/categorymanager;1"]
                           .getService(nsICategoryManager);

    catMan.deleteCategoryEntry("command-line-handler",
                               "m-scenaritest");
  },

  canUnload : function (compMgr) {
    return true;
  }
};

function NSGetModule(compMgr, fileSpec) {
  return Module;
}

==> SCENARIbuilder_3.6.001alpha_lin.tgz: bin/scTest/components/scTestClh.js <==


const nsISupports              = Components.interfaces.nsISupports;

const nsICategoryManager       = Components.interfaces.nsICategoryManager;
const nsIComponentRegistrar    = Components.interfaces.nsIComponentRegistrar;
const nsICommandLine           = Components.interfaces.nsICommandLine;
const nsICommandLineHandler    = Components.interfaces.nsICommandLineHandler;
const nsIFactory               = Components.interfaces.nsIFactory;
const nsIModule                = Components.interfaces.nsIModule;
const nsIPrefBranch            = Components.interfaces.nsIPrefBranch;
const nsISupportsString        = Components.interfaces.nsISupportsString;
const nsIWindowWatcher         = Components.interfaces.nsIWindowWatcher;
const nsIDOMWindow			   = Components.interfaces.nsIDOMWindow;



var scTestClh = {
  /* nsISupports */

  QueryInterface : function clh_QI(iid) {
    if (iid.equals(nsICommandLineHandler) ||
        iid.equals(nsIFactory) ||
        iid.equals(nsISupports))
      return this;

    throw Components.results.NS_ERROR_NO_INTERFACE;
  },

  /* nsICommandLineHandler */

  handle : function clh_handle(pCmdLine) {
	if (pCmdLine.preventDefault) return;
	
	var vPrefs = Components.classes["@mozilla.org/preferences-service;1"].getService(nsIPrefBranch);
	var vConsoleService = Components.classes["@mozilla.org/consoleservice;1"].getService(Components.interfaces.nsIConsoleService);
	
	try {
		var chromeURI = vPrefs.getCharPref("toolkit.defaultChromeURI");
		
		var vExtMgrService = Components.classes["@mozilla.org/extensions/manager;1"].getService(Components.interfaces.nsIExtensionManager);
		
		var vWinWatch = Components.classes["@mozilla.org/embedcomp/window-watcher;1"].getService(nsIWindowWatcher);
		var vEnum = vWinWatch.getWindowEnumerator(null);
		 

		var vChromeCode = pCmdLine.handleFlagWithParam("chromeCode", true);
		var vChromeContentUrl = pCmdLine.handleFlagWithParam("chromeContentUrl", true);
		var vManifest = "content " + vChromeCode + " " + vChromeContentUrl + "\n";
		vManifest    +=  "overlay chrome://scenaricms/content/wspmgr/packlist.xml " + vChromeContentUrl + "pack.xml\n";
		
		var vFolderService = Components.classes["@mozilla.org/file/directory_service;1"].getService(Components.interfaces.nsIProperties);
		var vFile = vFolderService.get("ProfD", Components.interfaces.nsIFile);
		vFile.append("extensions");
		if( ! vFile.exists()) vFile.create(Components.interfaces.nsIFile.DIRECTORY_TYPE, 0755);
		vFile.append("modeltest@scenari-platform.org");
		
		if( ! vFile.exists()) {

			vFile.create(Components.interfaces.nsIFile.DIRECTORY_TYPE, 0755);
			var vInstallRdf = vFile.clone();
			
			vInstallRdf.append("install.rdf");
			vInstallContent = '<?xml version="1.0" encoding="ISO-8859-1"?><RDF xmlns="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:em="http://www.mozilla.org/2004/em-rdf#"><Description about="urn:mozilla:install-manifest">';
			vInstallContent += '<em:id>modeltest@scenari-platform.org</em:id><em:name>modeltest</em:name><em:type>2</em:type><em:version>0.0.0</em:version><em:description>modeltest</em:description><em:creator>SCENARI</em:creator>';
			vInstallContent += '<em:targetApplication><Description><em:id>{96812ADD-F6D9-482A-B0EF-D4F1DE71D0E0}</em:id><em:minVersion>1.0</em:minVersion><em:maxVersion>99.*</em:maxVersion></Description></em:targetApplication>';
			vInstallContent += '</Description></RDF>';
			var vOutputStream = Components.classes["@mozilla.org/network/file-output-stream;1"].createInstance( Components.interfaces.nsIFileOutputStream );
			vOutputStream.init(vInstallRdf, 0x04 | 0x08 | 0x20, 0644, 0 );
			vOutputStream.write(vInstallContent, vInstallContent.length);
			vOutputStream.close();
					

			vExtMgrService.start(pCmdLine);

		}
			

		vFile.append("chrome.manifest");
		var vOutputStream = Components.classes["@mozilla.org/network/file-output-stream;1"].createInstance(Components.interfaces.nsIFileOutputStream);
		vOutputStream.init(vFile, 0x04 | 0x08 | 0x20, 0644, 0 );
		vOutputStream.write(vManifest, vManifest.length);
		vOutputStream.close();

		var vChromeRegistry = Components.classes["@mozilla.org/chrome/chrome-registry;1"].getService(Components.interfaces.nsIChromeRegistry);
		vChromeRegistry.checkForNewChrome();
		

		var vCacheImg = Components.classes["@mozilla.org/image/cache;1"].getService(Components.interfaces.imgICache);
		vCacheImg.clearCache(true);
		
		var vWspReg = Components.classes["@scenari.com/wspregistryservice;1"].getService(Components.interfaces.scIWspRegistryService);
		

		var vEnableWspList = vWspReg.getEnabledWsps();
		var vLen = vEnableWspList.Count();
		for(var i = 0; i < vLen; i++) {
			var vWsp = vEnableWspList.GetElementAt(i).QueryInterface(Components.interfaces.scIWsp);
			vWspReg.setActiveWsp(vWsp.getIdServer(), vWsp.getCode(), false);
		}
		

		var vWspCode = pCmdLine.handleFlagWithParam("wspCode", true);
		var vUrlServer = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch).getCharPref("scenari.urlServerLocal");
		var vServer = vWspReg.addServer(vUrlServer, "", "", null);
		vWspReg.addWsp(vServer.getId(), vWspCode, "", true);
		

		var vNewWin = vWinWatch.openWindow(null, chromeURI, "_blank", "chrome,dialog=no,all", pCmdLine);
	
		pCmdLine.preventDefault = true;
		

		while (vEnum.hasMoreElements()) {
			var vDomWindow = vEnum.getNext().QueryInterface(nsIDOMWindow);
			if(vNewWin != vDomWindow) try{vDomWindow.close();} catch (e) {}
		}
	} catch (e) {
		debug("init Failed : "+e);
	}
	
  },

  helpInfo : "SCENARI test",

  /* nsIFactory */
  createInstance : function mdh_CI(outer, iid) {
    if (outer != null) throw Components.results.NS_ERROR_NO_AGGREGATION;
    return this.QueryInterface(iid);
  },

  lockFactory : function mdh_lock(lock) {
    /* no-op */
  }
};

function debug(pText){
	var vConsoleService = Components.classes["@mozilla.org/consoleservice;1"].getService(Components.interfaces.nsIConsoleService);
	vConsoleService.logStringMessage(pText);
}
function dialogAlert(pText, pTitle){
	var vService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].getService(Components.interfaces.nsIPromptService);
	vService.alert(null, pTitle ? pTitle : "SCENARI - Message", pText);
}



const clh_contractID = "@scenari/scenaritest-clh;1";
const clh_CID = Components.ID("{3CAE0595-E91E-402C-8936-4B886A7DE3FD}");

var Module = {
  /* nsISupports */

  QueryInterface : function mod_QI(iid) {
    if (iid.equals(nsIModule) ||
        iid.equals(nsISupports))
      return this;

    throw Components.results.NS_ERROR_NO_INTERFACE;
  },

  /* nsIModule */

  getClassObject : function mod_gch(compMgr, cid, iid) {
    if (cid.equals(clh_CID))
      return scTestClh.QueryInterface(iid);

    throw components.results.NS_ERROR_FAILURE;
  },

  registerSelf : function mod_regself(compMgr, fileSpec, location, type) {
    var compReg = compMgr.QueryInterface(nsIComponentRegistrar);

    compReg.registerFactoryLocation(clh_CID,
                                    "scTestClh",
                                    clh_contractID,
                                    fileSpec,
                                    location,
                                    type);

    var catMan = Components.classes["@mozilla.org/categorymanager;1"]
                           .getService(nsICategoryManager);

    catMan.addCategoryEntry("command-line-handler",
                            "m-scenaritest",
                            clh_contractID, true, true);
  },

  unregisterSelf : function mod_unreg(compMgr, location, type) {
    var compReg = compMgr.QueryInterface(nsIComponentRegistrar);
    compReg.unregisterFactoryLocation(clh_CID, location);

    var catMan = Components.classes["@mozilla.org/categorymanager;1"]
                           .getService(nsICategoryManager);

    catMan.deleteCategoryEntry("command-line-handler",
                               "m-scenaritest");
  },

  canUnload : function (compMgr) {
    return true;
  }
};

function NSGetModule(compMgr, fileSpec) {
  return Module;
}
